tM(X, df = 1, alg = "alg3", mu.init = NULL, V.init = NULL, gamma.init = NULL, eps = 1e-06, maxiter = 100, na.action = na.fail)1 which corresponds to the Cauchy distribution.alg1, alg2 or alg3. alg3 is the default.alg2.alg2 is used.df > 0. Algorithm 2 is well defined only for degrees of freedom df > 1.
Algorithm 3 is the limiting case of Algorithm 2 with degrees of freedom df = 1.
The performance of the algorithms are compared in Arslan et al. (1995).
Note that cov.trob in the MASS package implements also a covariance estimate for a multivariate t-distribution.
That function provides for example also the possibility to fix the location. It requires however that the degrees of freedom exceeds 2.
Arslan, O., Constable, P.D.L. and Kent, J.T. (1995), Convergence behaviour of the EM algorithm for the multivariate t-distribution, Communications in Statistics, Theory and Methods, 24, 2981--3000.
cov.trob set.seed(654321)
cov.matrix <- matrix(c(3,2,1,2,4,-0.5,1,-0.5,2), ncol=3)
X <- rmvt(100, cov.matrix, 1)
tM(X)
rm(.Random.seed)
Run the code above in your browser using DataLab